# Generated by Django 5.0.1 on 2024-02-22 01:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0010_remove_arvdrugs_intecomm_li_name_b55bdc_idx_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Accompanied",
            fields=[
                (
                    "name",
                    models.CharField(
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                ("extra_value", models.CharField(max_length=250, null=True)),
                ("version", models.CharField(default="1.0", editable=False, max_length=35)),
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "custom_name",
                    models.CharField(
                        blank=True,
                        help_text="A custom name/value to use on export instead of or in addition to `name`",
                        max_length=25,
                        null=True,
                    ),
                ),
            ],
            options={
                "verbose_name": "Accompanied by",
                "verbose_name_plural": "Accompanied by",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "indexes": [
                    models.Index(
                        fields=["display_index", "display_name"],
                        name="intecomm_li_display_2b9504_idx",
                    )
                ],
            },
        ),
        migrations.CreateModel(
            name="MoneySources",
            fields=[
                (
                    "name",
                    models.CharField(
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                ("extra_value", models.CharField(max_length=250, null=True)),
                ("version", models.CharField(default="1.0", editable=False, max_length=35)),
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "custom_name",
                    models.CharField(
                        blank=True,
                        help_text="A custom name/value to use on export instead of or in addition to `name`",
                        max_length=25,
                        null=True,
                    ),
                ),
            ],
            options={
                "verbose_name": "Money sources",
                "verbose_name_plural": "Money sources",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "indexes": [
                    models.Index(
                        fields=["display_index", "display_name"],
                        name="intecomm_li_display_504729_idx",
                    )
                ],
            },
        ),
        migrations.CreateModel(
            name="TravelMethods",
            fields=[
                (
                    "name",
                    models.CharField(
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                ("extra_value", models.CharField(max_length=250, null=True)),
                ("version", models.CharField(default="1.0", editable=False, max_length=35)),
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "custom_name",
                    models.CharField(
                        blank=True,
                        help_text="A custom name/value to use on export instead of or in addition to `name`",
                        max_length=25,
                        null=True,
                    ),
                ),
            ],
            options={
                "verbose_name": "Travel methods",
                "verbose_name_plural": "Travel methods",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "indexes": [
                    models.Index(
                        fields=["display_index", "display_name"],
                        name="intecomm_li_display_e67514_idx",
                    )
                ],
            },
        ),
    ]



import re
from uuid import uuid4

from django.conf import settings
from django.contrib.auth.models import Permission, User
from django.contrib.sites.models import Site
from django.test import override_settings
from django.urls import reverse
from django_webtest import WebTest
from edc_constants.constants import HIV, UUID_PATTERN
from edc_test_utils.webtest import login
from model_bakery.baker import make_recipe

from intecomm_lists.models import Conditions

from ..intecomm_test_case_mixin import IntecommTestCaseMixin


class TestScreening(IntecommTestCaseMixin, WebTest):
    def setUp(self) -> None:
        super().setUp()
        self.user = User.objects.create_superuser("user_login", "u@example.com", "pass")
        self.user.is_active = True
        self.user.is_staff = True
        self.user.save()
        self.user.refresh_from_db()
        self.user.userprofile.sites.add(Site.objects.get(id=101))
        self.user.userprofile.sites.add(Site.objects.get(id=201))
        self.user.user_permissions.add(Permission.objects.get(codename="view_appointment"))

    @override_settings(SITE_ID=201, EDC_CONSENT_REMOVE_PATIENT_NAMES_FROM_COUNTRIES=["uganda"])
    def test_add_patient_log_with_names(self):
        changelist_url_name = (
            "intecomm_screening_admin:intecomm_screening_patientlog_changelist"
        )
        login(self, user=self.user, redirect_url=changelist_url_name)

        changelist_url = reverse(changelist_url_name)
        response = self.app.get(changelist_url, user=self.user)
        add_url = reverse("intecomm_screening_admin:intecomm_screening_patientlog_add")
        self.assertIn(add_url, response.text)
        response = self.app.get(add_url, user=self.user)
        self.assertIn("legal_name", response.text)
        self.assertIn("familiar_name", response.text)

        obj = make_recipe(
            "intecomm_screening.patientlog",
            legal_name="NAMEA AAAA",
            familiar_name="NAMEA AAAA",
            initials="NA",
            hospital_identifier=uuid4().hex,
            contact_number="123456789",
            site_id=settings.SITE_ID,
        )
        obj.conditions.add(Conditions.objects.get(name=HIV))
        obj.refresh_from_db()

        change_url = reverse(
            "intecomm_screening_admin:intecomm_screening_patientlog_change",
            args=(obj.id,),
        )
        response = self.app.get(change_url, user=self.user)
        self.assertIn(str(obj.legal_name), response.text)
        self.assertIn(str(obj.familiar_name), response.text)

    @override_settings(SITE_ID=101)
    def test_add_patient_log_without_names(self):
        changelist_url_name = (
            "intecomm_screening_admin:intecomm_screening_patientlogug_changelist"
        )
        login(self, user=self.user, redirect_url=changelist_url_name)

        changelist_url = reverse(changelist_url_name)
        response = self.app.get(changelist_url, user=self.user)
        add_url = reverse("intecomm_screening_admin:intecomm_screening_patientlogug_add")
        self.assertIn(add_url, response.text)
        response = self.app.get(add_url, user=self.user)
        self.assertNotIn("legal_name", response.text)
        self.assertNotIn("familiar_name", response.text)

        obj = make_recipe(
            "intecomm_screening.patientlogug",
            legal_name=str(uuid4()),
            familiar_name=str(uuid4()),
            initials="BB",
            hospital_identifier=uuid4().hex,
            contact_number="123456780",
            site_id=settings.SITE_ID,
        )
        obj.conditions.add(Conditions.objects.get(name=HIV))

        obj.refresh_from_db()
        self.assertTrue(re.match(UUID_PATTERN, str(obj.legal_name)))
        self.assertTrue(re.match(UUID_PATTERN, str(obj.familiar_name)))

        response = self.app.get(changelist_url, user=self.user)
        self.assertNotIn(str(obj.legal_name), response.text)
        self.assertNotIn(str(obj.familiar_name), response.text)

        change_url = reverse(
            "intecomm_screening_admin:intecomm_screening_patientlogug_change",
            args=(obj.id,),
        )

        response = self.app.get(change_url, user=self.user)
        self.assertNotIn(str(obj.legal_name), response.text)
        self.assertNotIn(str(obj.familiar_name), response.text)

    @override_settings(SITE_ID=201)
    def test_add_patient_log_with_names2(self):
        changelist_url_name = (
            "intecomm_screening_admin:intecomm_screening_patientlog_changelist"
        )
        login(self, user=self.user, redirect_url=changelist_url_name)

        changelist_url = reverse(changelist_url_name)
        response = self.app.get(changelist_url, user=self.user)
        add_url = reverse("intecomm_screening_admin:intecomm_screening_patientlog_add")
        self.assertIn(add_url, response.text)
        response = self.app.get(add_url, user=self.user)
        self.assertIn("legal_name", response.text)
        self.assertIn("familiar_name", response.text)

        obj = make_recipe(
            "intecomm_screening.patientlog",
            legal_name="Tianna Esperanza",
            familiar_name="Tianna Esperanza",
            initials="TE",
            hospital_identifier=uuid4().hex,
            contact_number="123456780",
            site_id=settings.SITE_ID,
        )
        obj.conditions.add(Conditions.objects.get(name=HIV))

        obj.refresh_from_db()

        response = self.app.get(changelist_url, user=self.user)
        self.assertIn(str(obj.legal_name), response.text)
        self.assertIn(str(obj.familiar_name), response.text)

        change_url = reverse(
            "intecomm_screening_admin:intecomm_screening_patientlog_change",
            args=(obj.id,),
        )

        response = self.app.get(change_url, user=self.user)
        self.assertIn(str(obj.legal_name), response.text)
        self.assertIn(str(obj.familiar_name), response.text)

    @override_settings(
        SITE_ID=None,
        EDC_CONSENT_REMOVE_PATIENT_NAMES_FROM_COUNTRIES=["uganda"],
        ALLOWED_HOSTS=["amana.tz.localhost"],
        LANGUAGES=[("en", "English"), ("sw", "Swahili")],
    )
    def test_add_patient_log_with_names_with_site_from_http_host(self):
        site_obj = Site.objects.get(id=201)
        site_obj.domain = "amana.tz.localhost"
        site_obj.save()

        changelist_url_name = (
            "intecomm_screening_admin:intecomm_screening_patientlog_changelist"
        )

        login(
            self,
            user=self.user,
            redirect_url=changelist_url_name,
            extra_environ=dict(HTTP_HOST="amana.tz.localhost"),
        )

        changelist_url = reverse(changelist_url_name)
        response = self.app.get(
            changelist_url,
            user=self.user,
            extra_environ=dict(HTTP_HOST="amana.tz.localhost"),
        )
        add_url = reverse("intecomm_screening_admin:intecomm_screening_patientlog_add")
        self.assertIn(add_url, response.text)
        response = self.app.get(
            add_url,
            user=self.user,
            extra_environ=dict(HTTP_HOST="amana.tz.localhost"),
        )
        self.assertIn("legal_name", response.text)
        self.assertIn("familiar_name", response.text)



# Generated by Django 4.1.7 on 2023-04-04 12:54

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0023_auto_20230404_0411"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="med_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Medication start date, if known",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="med_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Medication start date, if known",
            ),
        ),
    ]



from django import forms
from intecomm_form_validators.subject import SocialHarmsFormValidator

from ..models import SocialHarms
from .mixins import CrfModelFormMixin


class SocialHarmsForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = SocialHarmsFormValidator

    class Meta:
        model = SocialHarms
        fields = "__all__"



# Generated by Django 4.1.7 on 2023-05-04 16:00

import _socket
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("intecomm_subject", "0038_healtheconomics_welfare_other_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Icecapa",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "stability",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I am able to feel settled and secure in <B>all</B> areas of my life",
                            ),
                            (
                                "3",
                                "I am able to feel settled and secure in <B>many</B> areas of my life",
                            ),
                            (
                                "2",
                                "I am able to feel settled and secure in a <B>few</B> areas of my life",
                            ),
                            (
                                "1",
                                "I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Feeling settled and secure",
                    ),
                ),
                (
                    "attachment",
                    models.CharField(
                        choices=[
                            ("4", "I can have <B>a lot</B> of love, friendship and support"),
                            (
                                "3",
                                "I can have <B>quite a lot</B> of love, friendship and support",
                            ),
                            ("2", "I can have <B>a little</B> love, friendship and support"),
                            (
                                "1",
                                "I <B>cannot</B> have <B>any</B> love, friendship and support",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Love, friendship and support",
                    ),
                ),
                (
                    "autonomy",
                    models.CharField(
                        choices=[
                            ("4", "I am able to be <B>completely</B> independent"),
                            ("3", "I am able to be independent in <B>many</B> things"),
                            ("2", "I am able to be independent in <B>a few</B> things"),
                            ("1", "I am <B>unable</B> to be at all independent"),
                        ],
                        max_length=5,
                        verbose_name="Being independent",
                    ),
                ),
                (
                    "achievement",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I can achieve and progress in <B>all</B> aspects of my life",
                            ),
                            (
                                "3",
                                "I can achieve and progress in <B>many</B> aspects of my life",
                            ),
                            (
                                "2",
                                "I can achieve and progress in <B>a few</B> aspects of my life",
                            ),
                            (
                                "1",
                                "I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Achievement and progress",
                    ),
                ),
                (
                    "enjoyment",
                    models.CharField(
                        choices=[
                            ("4", "I can have a lot of enjoyment and pleasure"),
                            ("3", "I can have quite a lot of enjoyment and pleasure"),
                            ("2", "I can have a little enjoyment and pleasure"),
                            ("1", "I cannot have any enjoyment and pleasure"),
                        ],
                        max_length=5,
                        verbose_name="Enjoyment and pleasure",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "Overall quality of life (ICECAP-A V2)",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalIcecapa",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "stability",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I am able to feel settled and secure in <B>all</B> areas of my life",
                            ),
                            (
                                "3",
                                "I am able to feel settled and secure in <B>many</B> areas of my life",
                            ),
                            (
                                "2",
                                "I am able to feel settled and secure in a <B>few</B> areas of my life",
                            ),
                            (
                                "1",
                                "I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Feeling settled and secure",
                    ),
                ),
                (
                    "attachment",
                    models.CharField(
                        choices=[
                            ("4", "I can have <B>a lot</B> of love, friendship and support"),
                            (
                                "3",
                                "I can have <B>quite a lot</B> of love, friendship and support",
                            ),
                            ("2", "I can have <B>a little</B> love, friendship and support"),
                            (
                                "1",
                                "I <B>cannot</B> have <B>any</B> love, friendship and support",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Love, friendship and support",
                    ),
                ),
                (
                    "autonomy",
                    models.CharField(
                        choices=[
                            ("4", "I am able to be <B>completely</B> independent"),
                            ("3", "I am able to be independent in <B>many</B> things"),
                            ("2", "I am able to be independent in <B>a few</B> things"),
                            ("1", "I am <B>unable</B> to be at all independent"),
                        ],
                        max_length=5,
                        verbose_name="Being independent",
                    ),
                ),
                (
                    "achievement",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I can achieve and progress in <B>all</B> aspects of my life",
                            ),
                            (
                                "3",
                                "I can achieve and progress in <B>many</B> aspects of my life",
                            ),
                            (
                                "2",
                                "I can achieve and progress in <B>a few</B> aspects of my life",
                            ),
                            (
                                "1",
                                "I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Achievement and progress",
                    ),
                ),
                (
                    "enjoyment",
                    models.CharField(
                        choices=[
                            ("4", "I can have a lot of enjoyment and pleasure"),
                            ("3", "I can have quite a lot of enjoyment and pleasure"),
                            ("2", "I can have a little enjoyment and pleasure"),
                            ("1", "I cannot have any enjoyment and pleasure"),
                        ],
                        max_length=5,
                        verbose_name="Enjoyment and pleasure",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "historical Overall quality of life (ICECAP-A V2)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalEq5d3l",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "mobility",
                    models.CharField(
                        choices=[
                            ("no_problems_in_walking", "I have no problems in walking about"),
                            (
                                "some_problems_in_walking",
                                "I have some problems in walking about",
                            ),
                            ("confined_to_bed", "I am confined to bed"),
                        ],
                        max_length=45,
                        verbose_name="Mobility",
                    ),
                ),
                (
                    "self_care",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_with_self_care",
                                "I have no problems with self-care",
                            ),
                            (
                                "problems_washing_dressing_myself",
                                "I have some problems washing or dressing myself",
                            ),
                            (
                                "unable_to_wash_dress_myself",
                                "I am unable to wash or dress myself",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Self-care",
                    ),
                ),
                (
                    "usual_activities",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_performing_usual_activities",
                                "I have no problems with performing my usual activities",
                            ),
                            (
                                "some_problems_performing_usual_activities",
                                "I have some problems with performing my usual activities",
                            ),
                            (
                                "unable_to_perform_usual_activities",
                                "I am unable to perform my usual activities",
                            ),
                        ],
                        help_text="Example. work, study, housework, family or leisure activities",
                        max_length=45,
                        verbose_name="Usual activities",
                    ),
                ),
                (
                    "pain_discomfort",
                    models.CharField(
                        choices=[
                            ("no_pain_discomfort", "I have no pain or discomfort"),
                            ("moderate_pain_discomfort", "I have moderate pain or discomfort"),
                            ("extreme_pain_discomfort", "I have extreme pain or discomfort"),
                        ],
                        max_length=45,
                        verbose_name="Pain / Discomfort",
                    ),
                ),
                (
                    "anxiety_depression",
                    models.CharField(
                        choices=[
                            ("not_anxious_depressed", "I am not anxious or depressed"),
                            (
                                "moderately_anxious_depressed",
                                "I am moderately anxious or depressed",
                            ),
                            (
                                "extremely_anxious_depressed",
                                "I am extremely anxious or depressed",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Anxiety / Depression",
                    ),
                ),
                (
                    "health_today_score_slider",
                    models.CharField(
                        max_length=3, verbose_name="Visual score for how your health is TODAY"
                    ),
                ),
                (
                    "health_today_score_confirmed",
                    models.IntegerField(
                        help_text="This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "historical EuroQol EQ-5D-3L Instrument",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="Eq5d3l",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "mobility",
                    models.CharField(
                        choices=[
                            ("no_problems_in_walking", "I have no problems in walking about"),
                            (
                                "some_problems_in_walking",
                                "I have some problems in walking about",
                            ),
                            ("confined_to_bed", "I am confined to bed"),
                        ],
                        max_length=45,
                        verbose_name="Mobility",
                    ),
                ),
                (
                    "self_care",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_with_self_care",
                                "I have no problems with self-care",
                            ),
                            (
                                "problems_washing_dressing_myself",
                                "I have some problems washing or dressing myself",
                            ),
                            (
                                "unable_to_wash_dress_myself",
                                "I am unable to wash or dress myself",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Self-care",
                    ),
                ),
                (
                    "usual_activities",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_performing_usual_activities",
                                "I have no problems with performing my usual activities",
                            ),
                            (
                                "some_problems_performing_usual_activities",
                                "I have some problems with performing my usual activities",
                            ),
                            (
                                "unable_to_perform_usual_activities",
                                "I am unable to perform my usual activities",
                            ),
                        ],
                        help_text="Example. work, study, housework, family or leisure activities",
                        max_length=45,
                        verbose_name="Usual activities",
                    ),
                ),
                (
                    "pain_discomfort",
                    models.CharField(
                        choices=[
                            ("no_pain_discomfort", "I have no pain or discomfort"),
                            ("moderate_pain_discomfort", "I have moderate pain or discomfort"),
                            ("extreme_pain_discomfort", "I have extreme pain or discomfort"),
                        ],
                        max_length=45,
                        verbose_name="Pain / Discomfort",
                    ),
                ),
                (
                    "anxiety_depression",
                    models.CharField(
                        choices=[
                            ("not_anxious_depressed", "I am not anxious or depressed"),
                            (
                                "moderately_anxious_depressed",
                                "I am moderately anxious or depressed",
                            ),
                            (
                                "extremely_anxious_depressed",
                                "I am extremely anxious or depressed",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Anxiety / Depression",
                    ),
                ),
                (
                    "health_today_score_slider",
                    models.CharField(
                        max_length=3, verbose_name="Visual score for how your health is TODAY"
                    ),
                ),
                (
                    "health_today_score_confirmed",
                    models.IntegerField(
                        help_text="This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["subject_visit", "site", "id"], name="intecomm_su_subject_9061b4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="intecomm_su_subject_66afdb_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["subject_visit", "site", "id"], name="intecomm_su_subject_26cbd6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="intecomm_su_subject_ea2acc_idx",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-10 03:00

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0097_alter_healtheconomicsincome_external_remit_value_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, STOP and save the form.",
                max_length=15,
                verbose_name="Are you the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_age",
            field=models.IntegerField(
                blank=True,
                help_text="In years as of today",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(18),
                    django.core.validators.MaxValueValidator(110),
                ],
                verbose_name="How old is the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the household head female or male?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, STOP and save the form.",
                max_length=15,
                verbose_name="Are you the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_age",
            field=models.IntegerField(
                blank=True,
                help_text="In years as of today",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(18),
                    django.core.validators.MaxValueValidator(110),
                ],
                verbose_name="How old is the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the household head female or male?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
    ]



from django.db import models
from edc_constants.choices import TRUE_FALSE_DONT_KNOW
from edc_model.models import BaseUuidModel

from ..choices import HOUSEHOLD_YES_NO_CHOICES
from ..model_mixins import CrfModelMixin


class FamilyHistory(CrfModelMixin, BaseUuidModel):
    htn_in_household = models.CharField(
        verbose_name="Do you know if anyone else in your household has high blood pressure?",
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    dm_in_household = models.CharField(
        verbose_name="Do you know if anyone else in your household has diabetes?",
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    hiv_in_household = models.CharField(
        verbose_name="Do you know if anyone else in your household has HIV?",
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    high_bp_bs_tf = models.CharField(
        verbose_name=(
            "High blood pressure and high blood sugar can cause many "
            "illnesses like heart attacks, stroke, kidney failure"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    overweight_tf = models.CharField(
        verbose_name=(
            "Being overweight protects from high blood pressure and high blood sugar"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    salty_foods_tf = models.CharField(
        verbose_name="Salty food protects from high blood sugar",
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    excercise_tf = models.CharField(
        verbose_name=(
            "Regular exercise is important for people with high blood "
            "pressure or high blood sugar even if they are taking "
            "medicines for these conditions."
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    take_medicine_tf = models.CharField(
        verbose_name="Drugs for blood sugar and blood pressure can make you unwell",
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    stop_htn_meds_tf = models.CharField(
        verbose_name=(
            "It is best to stop taking blood pressure pills when "
            "you feel better and start pill taking again when you feel sick"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    traditional_htn_tf = models.CharField(
        verbose_name=(
            "Herbs and traditional medicine are better for "
            "managing blood pressure than pills and medicines"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    stop_dm_meds_tf = models.CharField(
        verbose_name=(
            "It is best to stop taking blood sugar medicines when "
            "you feel better and start pill taking again when you feel sick"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    traditional_dm_tf = models.CharField(
        verbose_name=(
            "Herbs and traditional medicine are better for managing "
            "diabetes than pills and medicines"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    dm_cause_tf = models.CharField(
        verbose_name="Having drinks with sugar (e.g. tea/coffee) causes diabetes",
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Family History and Knowledge"
        verbose_name_plural = "Family History and Knowledge"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from .community_care_location import CommunityCareLocation
from .patient_followup_call import PatientFollowupCall
from .patient_group import PatientGroup
from .patient_group_appointment import PatientGroupAppointment
from .patient_group_meeting import PatientGroupMeeting
from .signals import (
    create_or_update_patientgroup_meeting_on_post_save,
    update_patientgroup_on_post_save,
    update_patientgroup_patients_from_patientlog_m2ms_on_m2m_changed,
)
from .utils import add_to_group, remove_from_group



from django.contrib import admin
from django.template.loader import render_to_string
from django.utils.translation import gettext as _
from django_audit_fields import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple

from ...admin_site import intecomm_subject_admin
from ...forms import CareseekingAForm
from ...models import CareseekingA
from ..modeladmin_mixins import CrfModelAdmin


@admin.register(CareseekingA, site=intecomm_subject_admin)
class CareseekingAAdmin(
    CrfModelAdmin,
):
    form = CareseekingAForm

    additional_instructions = render_to_string(
        "intecomm_subject/careseeking_a_instructions.html", context={}
    )

    fieldsets = (
        (
            _("PART A: INFORMATION ON TODAY’S VISIT"),
            {"fields": ("subject_visit", "report_datetime")},
        ),
        (
            _("A1: Travel, expenses and reason for today's visit"),
            {
                "fields": (
                    "travel_method",
                    "travel_time",
                    "travel_cost",
                    "food_cost",
                    "care_visit_reason",
                    "care_visit_reason_other",
                    "care_visit_cost",
                )
            },
        ),
        (
            _("A3: Medication costs for today's visit"),
            {
                "fields": (
                    "med_prescribed",
                    "med_conditions",
                    "med_conditions_other",
                    "med_collected",
                    "med_not_collected_reason",
                    "med_not_collected_reason_other",
                    "med_cost_tot",
                    "med_cost_hiv",
                    "med_cost_htn",
                    "med_cost_dm",
                    "med_cost_other",
                    "med_collected_location",
                    "med_collected_location_other",
                )
            },
        ),
        (
            _("A4: Diagnostic costs for today's visit"),
            {
                "fields": (
                    "tests_requested",
                    "tests_done",
                    "tests_not_done_reason",
                    "tests_not_done_other",
                    "tests_cost",
                )
            },
        ),
        (
            _("A5: Time for today's visit"),
            {
                "fields": (
                    "care_visit_duration",
                    "with_hcw_duration",
                    "missed_activities",
                    "missed_activities_other",
                )
            },
        ),
        (
            _("A6: Referral from today's visit"),
            {
                "fields": (
                    "referral",
                    "referral_type",
                    "referral_facility",
                )
            },
        ),
        (
            _("A7: People who accompanied you to today's visit"),
            {
                "fields": (
                    "accompany",
                    "accompany_num",
                    "accompany_wait",
                    "accompany_alt",
                    "accompany_alt_other",
                )
            },
        ),
        (
            _("A8: Your expenses for today's visit"),
            {
                "fields": (
                    "money_sources",
                    "money_sources_other",
                    "money_source_main",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = [
        "travel_method",
        "care_visit_reason",
        "med_conditions",
        "money_sources",
    ]

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "med_prescribed": admin.VERTICAL,
        "med_collected": admin.VERTICAL,
        "med_not_collected_reason": admin.VERTICAL,
        "tests_requested": admin.VERTICAL,
        "tests_done": admin.VERTICAL,
        "tests_not_done_reason": admin.VERTICAL,
        "missed_activities": admin.VERTICAL,
        "referral": admin.VERTICAL,
        "referral_type": admin.VERTICAL,
        "referral_facility": admin.VERTICAL,
        "money_source_main": admin.VERTICAL,
        "accompany": admin.VERTICAL,
        "accompany_wait": admin.VERTICAL,
        "accompany_alt": admin.VERTICAL,
        "med_collected_location": admin.VERTICAL,
    }



from django.contrib.admin import SimpleListFilter
from django.db.models import Count, QuerySet
from edc_constants.choices import YES_NO_PENDING_NA
from edc_constants.constants import NO, NOT_APPLICABLE, PENDING, YES
from edc_sites.site import sites

from intecomm_group.models import PatientGroup


class PatientGroupListFilter(SimpleListFilter):
    title = "Group"
    parameter_name = "subject_identifier"

    def lookups(self, request, model_admin):
        site_ids = sites.get_view_only_site_ids_for_user(request=request)
        group_names = [
            (dct["name"], dct["name"].title())
            for dct in PatientGroup.objects.filter(randomized=True, site__in=site_ids)
            .values("name")
            .annotate(count=Count("name"))
        ]
        return tuple(group_names)

    def queryset(self, request, queryset):
        if self.value() and self.value() != "none":
            appt_subject_identifiers = [
                dct["subject_identifier"]
                for dct in queryset.values("subject_identifier").annotate(
                    count=Count("subject_identifier")
                )
            ]
            subject_identifiers = [
                dct["patients__subject_identifier"]
                for dct in PatientGroup.objects.filter(name=self.value())
                .values("patients__subject_identifier")
                .annotate(count=Count("patients__subject_identifier"))
            ]
            subject_identifiers = [
                v for v in subject_identifiers if v in appt_subject_identifiers
            ]
            queryset = queryset.filter(subject_identifier__in=subject_identifiers)
        return queryset


class VlStatusListFilter(SimpleListFilter):
    title = "VL Resulted"

    parameter_name = "vl_resulted"
    field_name = "has_vl"

    def lookups(self, request, model_admin) -> tuple:
        return YES_NO_PENDING_NA

    def queryset(self, request, queryset) -> QuerySet | None:
        qs = None
        if self.value() == YES:
            qs = queryset.filter(has_vl=YES)
        if self.value() == NO:
            qs = queryset.filter(has_vl=NO)
        if self.value() == PENDING:
            qs = queryset.filter(has_vl=PENDING)
        if self.value() == NOT_APPLICABLE:
            qs = queryset.filter(has_vl=NOT_APPLICABLE)
        return qs



from __future__ import annotations

import re

from django.apps import apps as django_apps
from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from django.db.models import UniqueConstraint
from django.utils.html import format_html
from django_crypto_fields.fields import EncryptedCharField, EncryptedTextField
from edc_consent.utils import get_remove_patient_names_from_countries
from edc_constants.choices import GENDER, YES_NO_TBD
from edc_constants.constants import DM, HIV, HTN, TBD, UUID_PATTERN
from edc_model.models import BaseUuidModel, HistoricalRecords, NameFieldsModelMixin
from edc_model.validators.phone import phone_number
from edc_model_fields.fields import InitialsField, OtherCharField
from edc_sites.managers import CurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_sites.site import sites
from edc_utils import get_utcnow, get_uuid

from intecomm_lists.models import Conditions, ScreeningRefusalReasons

from ..identifiers import FilingIdentifier, PatientLogIdentifier
from ..utils import validate_screening_identifier, validate_subject_identifier
from .proxy_models import Site


class PatientLogManager(models.Manager):
    use_in_migrations = True

    def get_by_natural_key(self, legal_name):
        return self.get(legal_name=legal_name)


class PatientLog(SiteModelMixin, NameFieldsModelMixin, BaseUuidModel):
    filing_identifier = models.CharField(
        verbose_name="Filing number",
        max_length=36,
        blank=True,
        unique=True,
        help_text=format_html(
            "Auto-populated when form is saved. <BR>"
            "This is a sequential-like identifier to label this patient's paper file"
        ),
    )
    patient_log_identifier = models.CharField(
        verbose_name="Patient Log Reference",
        max_length=36,
        unique=True,
        blank=True,
        help_text=format_html(
            "Auto-populated when form is saved. <BR>"
            "You may prefer to use the FILING NUMBER. <BR>"
            "This identifier is replaced by the 'screening identifier' if the patient screens "
            "for the INTECOMM trial"
        ),
    )

    screening_identifier = models.CharField(
        max_length=36,
        default=get_uuid,
        unique=True,
        help_text="Auto populated when screening form is complete",
    )

    screening_datetime = models.DateTimeField(
        null=True,
        blank=True,
        help_text="Auto populated when screening form is complete",
    )

    subject_identifier = models.CharField(
        max_length=36,
        default=get_uuid,
        unique=True,
        help_text="Auto populated when consent form is complete",
    )

    consent_datetime = models.DateTimeField(
        null=True,
        blank=True,
        help_text="Auto populated when consent form is complete",
    )

    group_identifier = models.CharField(
        max_length=25,
        null=True,
        blank=True,
        help_text="Auto populated when group is randomized",
    )

    initials = InitialsField()

    gender = models.CharField(choices=GENDER, max_length=10, blank=False)

    age_in_years = models.IntegerField(
        verbose_name="Age",
        validators=[MinValueValidator(18), MaxValueValidator(110)],
    )

    report_datetime = models.DateTimeField(default=get_utcnow)

    site = models.ForeignKey(
        Site,
        verbose_name="Which site is this?",
        on_delete=models.PROTECT,
        blank=False,
        help_text="This question is asked to confirm you are logged in to the correct site.",
    )

    hospital_identifier = EncryptedCharField(
        verbose_name="Hospital identifier",
        unique=True,
        blank=False,
        help_text="Must be unique",
    )

    last_4_hospital_identifier = EncryptedCharField(
        verbose_name="Last 4 digits of hospital_identifier",
        null=True,
        editable=False,
        help_text="auto-populated",
    )

    contact_number = EncryptedCharField(
        blank=False, validators=[phone_number], help_text="If unknown, type 'UNKNOWN'"
    )

    alt_contact_number = EncryptedCharField(null=True, blank=True, validators=[phone_number])

    last_4_contact_number = EncryptedCharField(
        verbose_name="Last 4 digits of contact number",
        null=True,
        editable=False,
        help_text="auto-populated",
    )

    may_contact = models.CharField(
        verbose_name="Has the patient agreed to be contacted prior to consent?",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
    )

    location_description = EncryptedTextField(
        null=True, blank=True, help_text="Street, landmarks near home, etc"
    )

    conditions = models.ManyToManyField(
        Conditions,
        limit_choices_to={"name__in": [HIV, DM, HTN]},
        verbose_name="Diagnoses",
    )

    stable = models.CharField(
        verbose_name="Do the facility health care staff consider the patient stable in care",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        help_text="Refer to the SOP for the definition of 'stable'.",
    )

    last_appt_date = models.DateField(
        verbose_name="When was the patient last seen at this health facility",
        null=True,
        blank=True,
        help_text=(
            "If known, the last appointment may help to estimate the next appointment or "
            "the expected frequency of routine appointments"
        ),
    )

    next_appt_date = models.DateField(
        verbose_name="Next scheduled routine appointment at this health facility",
        null=True,
        blank=True,
        help_text="If known, this date will help prioritize efforts to contact the patient",
    )

    first_health_talk = models.CharField(
        verbose_name="Attended general health talk",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
    )

    first_health_talk_date = models.DateField(
        verbose_name="General talk date",
        null=True,
        blank=True,
    )

    second_health_talk = models.CharField(
        verbose_name="Attended sensitisation session",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
    )

    second_health_talk_date = models.DateField(
        verbose_name="Sensitisation session date", null=True, blank=True
    )

    call_attempts = models.IntegerField(default=0, help_text="auto-updated", blank=True)

    willing_to_screen = models.CharField(
        verbose_name="Has the patient agreed to be screened for the INTECOMM study",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
    )

    screening_refusal_reason = models.ForeignKey(
        ScreeningRefusalReasons,
        on_delete=models.PROTECT,
        verbose_name="Reason subject unwilling to screen",
        null=True,
        blank=False,
    )

    screening_refusal_reason_other = OtherCharField()

    printed = models.BooleanField(default=False)

    comment = models.CharField(max_length=250, null=True, blank=True)

    objects = PatientLogManager()
    on_site = CurrentSiteManager()
    history = HistoricalRecords(inherit=True)

    def __str_safe__(self):
        g = "G" if self.group_identifier else ""
        return (
            f"{self.patient_log_identifier} {self.age_in_years}{self.gender} "
            f"({self.site.id}){g}"
        )

    def __str__(self):
        remove_patient_names = False
        g = "G" if self.group_identifier else ""
        for country in get_remove_patient_names_from_countries():
            if self.site and self.site.id in [
                s.site_id for s in sites.get_by_country(country, aslist=True)
            ]:
                remove_patient_names = True
                break
        if remove_patient_names or re.match(UUID_PATTERN, str(self.legal_name)):
            return format_html(
                f"{self.filing_identifier} {self.initials} "
                f"{self.age_in_years}{self.gender} ({self.site.id}){g}"
            )
        return format_html(
            f"{self.legal_name.upper()}-{self.contact_number[-4:]} {self.initials} "
            f"{self.age_in_years}{self.gender} ({self.site.id}){g}"
        )

    def save(self, *args, **kwargs):
        if not kwargs.get("update_fields"):
            if not re.match(UUID_PATTERN, str(self.legal_name or "")):
                self.legal_name = self.legal_name.upper()
            if not re.match(UUID_PATTERN, str(self.familiar_name or "")):
                self.familiar_name = self.familiar_name.upper()
            self.initials = self.initials.upper()
            self.last_4_contact_number = self.contact_number[-4:]
            self.last_4_hospital_identifier = self.hospital_identifier[-4:]
            if not self.filing_identifier or re.match(
                UUID_PATTERN, str(self.filing_identifier)
            ):
                self.filing_identifier = FilingIdentifier(site_id=self.site.id).identifier
            if not self.patient_log_identifier or re.match(
                UUID_PATTERN, str(self.patient_log_identifier)
            ):
                self.patient_log_identifier = PatientLogIdentifier().identifier
        validate_screening_identifier(
            self.screening_identifier,
            subject_screening_model_cls=self.subject_screening_model_cls,
            calling_model=self,
        )
        validate_subject_identifier(
            self.subject_identifier,
            subject_consent_model_cls=self.subject_consent_model_cls,
            calling_model=self,
        )
        super().save(*args, **kwargs)

    def natural_key(self):
        return (self.legal_name,)  # noqa

    @property
    def patient_group(self):
        return self.patientgroup_set.all().first()

    @property
    def subject_screening_model_cls(self):
        return django_apps.get_model("intecomm_screening.subjectscreening")

    @property
    def subject_consent_model_cls(self):
        return django_apps.get_model("intecomm_consent.subjectconsent")

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Patient Log"
        verbose_name_plural = "Patient Log"
        constraints = [
            UniqueConstraint(
                fields=["legal_name", "initials"], name="%(app_label)s_%(class)s_legal_n_uniq"
            )
        ]



# Generated by Django 4.2.3 on 2023-07-26 14:58

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        ("intecomm_screening", "0049_healthfacility"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthtalklog",
            name="health_facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthtalklog",
            name="health_facility",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
        migrations.AddField(
            model_name="idenfifierformat",
            name="health_facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
    ]



from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin
from edc_visit_schedule.model_mixins import OffScheduleModelMixin

from ..constants import OFFSCHEDULE_COMM_ACTION


class OffScheduleComm(SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
    action_name = OFFSCHEDULE_COMM_ACTION
    offschedule_compare_dates_as_datetimes = False

    class Meta(OffScheduleModelMixin.Meta, ActionModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Off-schedule community-based integrated care"
        verbose_name_plural = "Off-schedule community-based integrated care"
        indexes = (
            OffScheduleModelMixin.Meta.indexes
            + ActionModelMixin.Meta.indexes
            + BaseUuidModel.Meta.indexes
            + [
                models.Index(
                    fields=[
                        "id",
                        "subject_identifier",
                        "action_identifier",
                        "offschedule_datetime",
                        "site",
                    ]
                )
            ]
        )



from django.utils.translation import gettext_lazy as _
from edc_crf.model_mixins import SingletonCrfModelMixin
from edc_he.model_mixins import HouseholdHeadModelMixin, HouseholdModelMixin
from edc_model.models import BaseUuidModel

from ...model_mixins import CrfModelMixin


class HealthEconomicsHouseholdHead(
    SingletonCrfModelMixin,
    HouseholdHeadModelMixin,
    HouseholdModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    # TODO: collapse hoh_ethnicity choices as per last revision (v3)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = _("Health Economics: Household head")
        verbose_name_plural = _("Health Economics: Household head")
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from __future__ import annotations

from dateutil.relativedelta import relativedelta
from edc_visit_schedule.constants import MONTH0, MONTH1, MONTH12
from edc_visit_schedule.visit import Visit

from .crfs import crfs_d1, crfs_followup, crfs_missed, crfs_month12, crfs_prn
from .requisitions import (
    requisitions_d1,
    requisitions_followup,
    requisitions_prn,
    requisitions_unscheduled,
)

visit00 = Visit(
    code=MONTH0,
    title="Baseline",
    add_window_gap_to_lower=False,
    allow_unscheduled=True,
    crfs=crfs_d1,
    crfs_missed=crfs_missed,
    crfs_prn=crfs_prn,
    crfs_unscheduled=crfs_followup,
    facility_name="5-day-clinic",
    rbase=relativedelta(day=0),
    requisitions=requisitions_d1,
    requisitions_prn=requisitions_prn,
    requisitions_unscheduled=requisitions_unscheduled,
    rlower=relativedelta(days=0),
    rupper=relativedelta(days=0),
    timepoint=0,
)


# facility visit01
visit01 = Visit(
    code=MONTH1,
    title="Followup month 1",
    add_window_gap_to_lower=True,
    allow_unscheduled=True,
    crfs=crfs_followup,
    crfs_missed=crfs_missed,
    crfs_prn=crfs_prn,
    crfs_unscheduled=crfs_followup,
    facility_name="5-day-clinic",
    rbase=relativedelta(months=1),
    requisitions=requisitions_followup,
    requisitions_prn=requisitions_prn,
    requisitions_unscheduled=requisitions_unscheduled,
    rlower=relativedelta(days=28),
    rupper=relativedelta(days=15),
    timepoint=1,
)


visit12 = Visit(
    code=MONTH12,
    title="Month 12 (End of study)",
    add_window_gap_to_lower=True,
    allow_unscheduled=True,
    crfs=crfs_month12,
    crfs_missed=crfs_missed,
    crfs_prn=crfs_prn,
    crfs_unscheduled=crfs_followup,
    facility_name="5-day-clinic",
    rbase=relativedelta(months=12),
    requisitions=requisitions_followup,
    requisitions_prn=requisitions_prn,
    requisitions_unscheduled=requisitions_unscheduled,
    rlower=relativedelta(days=13),
    rupper=relativedelta(months=3),
    timepoint=12,
)


def get_visit_code(mnth: int):
    if mnth < 10:
        return f"10{mnth*10}"
    return f"1{mnth*10}"


def get_followup_visit(month, start: int | None = None, allow_unscheduled: bool | None = None):
    start = 0 if start is None else start
    allow_unscheduled = False if allow_unscheduled is None else allow_unscheduled
    if month == start or month >= 12:
        raise ValueError(
            f"Invalid month number. Follow visits are from {start}-11. Got {month}."
        )
    rlower = relativedelta(days=13)
    rupper = relativedelta(days=15)
    return Visit(
        code=get_visit_code(month),
        title=f"Followup month {month}",
        add_window_gap_to_lower=True,
        allow_unscheduled=allow_unscheduled,
        crfs=crfs_followup,
        crfs_missed=crfs_missed,
        crfs_prn=crfs_prn,
        crfs_unscheduled=crfs_followup,
        facility_name="5-day-clinic",
        rbase=relativedelta(months=month),
        requisitions=requisitions_followup,
        requisitions_prn=requisitions_prn,
        requisitions_unscheduled=requisitions_unscheduled,
        rlower=rlower,
        rupper=rupper,
        timepoint=month,
    )



from django.db import models
from edc_constants.choices import YES_NO, YES_NO_NA
from edc_constants.constants import NO
from edc_model.models import BaseUuidModel
from edc_vitals.model_mixins import BloodPressureModelMixin
from edc_vitals.models import (
    HeartRateField,
    HeightField,
    RespiratoryRateField,
    TemperatureField,
    WaistCircumferenceField,
    WeightField,
)

from ..choices import ESTIMATED_MEASURED_CHOICES
from ..model_mixins import CrfModelMixin


class Vitals(
    BloodPressureModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    weight = WeightField(null=True, blank=True)

    weight_determination = models.CharField(
        verbose_name="Is weight estimated or measured?",
        max_length=15,
        choices=ESTIMATED_MEASURED_CHOICES,
    )

    bp_one_taken = models.CharField(
        "Was the first blood pressure reading done",
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    bp_one_not_taken_reason = models.CharField(
        "If not done, please explain", max_length=50, null=True, blank=True
    )

    bp_two_taken = models.CharField(
        "Was the second blood pressure reading done",
        max_length=15,
        choices=YES_NO_NA,
        null=True,
        blank=False,
    )

    bp_two_not_taken_reason = models.CharField(
        "If not done, please explain", max_length=50, null=True, blank=True
    )

    severe_htn = models.CharField(
        verbose_name="Does the patient have severe hypertension?",
        max_length=15,
        choices=YES_NO_NA,
        help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
        default=NO,
    )

    heart_rate = HeartRateField(null=True, blank=True)

    respiratory_rate = RespiratoryRateField(null=True, blank=True)

    temperature = TemperatureField(null=True, blank=True)

    height = HeightField(null=True, blank=True)

    waist = WaistCircumferenceField(null=True, blank=True)

    hip = models.DecimalField(
        verbose_name="Hip circumference:",
        decimal_places=1,
        max_digits=5,
        null=True,
        blank=True,
        help_text="in centimeters",
    )

    comments = models.TextField(null=True, blank=True)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Vitals"
        verbose_name_plural = "Vitals"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from .assets import HealthEconomicsAssets
from .careseeking_a import CareseekingA
from .careseeking_b import CareseekingB
from .household_head import HealthEconomicsHouseholdHead
from .income import HealthEconomicsIncome
from .patient import HealthEconomicsPatient
from .property import HealthEconomicsProperty



# Generated by Django 4.2.7 on 2023-12-05 20:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0011_alter_aefollowup_options_alter_aeinitial_options_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="aefollowup",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_a0869e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aefollowup",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__3099a7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aefollowup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_d686c6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aefollowup",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_4e2aff_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aeinitial",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_155c2e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aeinitial",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__0c4217_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aeinitial",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_fdff72_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aeinitial",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_4bd6c1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aesusar",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_50e2e0_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aesusar",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__feb740_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aesusar",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_ae0678_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aesusar",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_927aee_idx"
            ),
        ),
    ]



from django import forms

from ..models import SubjectConsentUg
from .modelform_mixins import SubjectConsentModelFormMixin


class SubjectConsentUgForm(
    SubjectConsentModelFormMixin,
    forms.ModelForm,
):
    class Meta(SubjectConsentModelFormMixin.Meta):
        model = SubjectConsentUg



# Generated by Django 4.2.4 on 2023-08-23 15:54

import _socket
import django.core.validators
import django_audit_fields.fields.hostname_modification_field
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0109_alter_healtheconomicsassets_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcd4result",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalcd4result",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalcd4result",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcd4result",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalnote",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalnote",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalnote",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalnote",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsbaseline",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsbaseline",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsbaseline",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsbaseline",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsfollowup",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsfollowup",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsfollowup",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsfollowup",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In the last month, how many days did you miss taking your medication",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In the last month, how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaleq5d3l",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaleq5d3l",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaleq5d3l",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaleq5d3l",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
    ]



def get_first_fieldset():
    return (
        None,
        {
            "fields": (
                "patient_log_identifier",
                "filing_identifier",
                "report_datetime",
                "site",
            )
        },
    )


def get_names_and_basic_demographics_fieldset(include_pii=None):
    fields = []
    if include_pii:
        fields.extend(["legal_name", "familiar_name"])
    fields.extend(
        [
            "initials",
            "hospital_identifier",
            "gender",
            "age_in_years",
        ]
    )

    return (
        "Name and basic demographics",
        {"fields": tuple(fields)},
    )


def get_contact_fieldset():
    return (
        "Contact",
        {
            "fields": (
                "contact_number",
                "alt_contact_number",
                "may_contact",
            )
        },
    )


def get_address_fielset():
    return (
        "Address / Location",
        {"fields": ("location_description",)},
    )


def get_health_fieldset():
    return (
        "Health",
        {
            "description": "Select one or more conditions with a documented diagnoses",
            "fields": (
                "conditions",
                "stable",
            ),
        },
    )


def get_health_talks_fieldset():
    return (
        "Health talks",
        {
            "fields": (
                "first_health_talk",
                "first_health_talk_date",
                "second_health_talk",
                "second_health_talk_date",
            )
        },
    )


def get_appointment_fieldset():
    return (
        "Appointments",
        {
            "fields": (
                "last_appt_date",
                "next_appt_date",
            )
        },
    )


def get_willingness_to_screen_fieldset():
    return (
        "Willingness to screen",
        {
            "description": (
                "This section may be left blank until a decision is made. If and when the "
                "screening form is submitted, the response here will be "
                "automatically updated by the EDC"
            ),
            "fields": (
                "willing_to_screen",
                "screening_refusal_reason",
                "screening_refusal_reason_other",
            ),
        },
    )


def get_screening_and_consent_fieldset():
    return (
        "Screening and Consent",
        {
            "classes": ("collapse",),
            "fields": (
                "comment",
                "screening_identifier",
                "screening_datetime",
                "subject_identifier",
                "consent_datetime",
            ),
        },
    )


def get_group_fieldset():
    return (
        "Group",
        {"classes": ("collapse",), "fields": ("group_identifier",)},
    )



# Generated by Django 4.2.1 on 2023-07-02 12:48

from django.db import migrations
from django.db.migrations import RunPython
from tqdm import tqdm


def update_patient_log_identifier(apps, schema_editor):
    subjectscreening_cls = apps.get_model("intecomm_screening.subjectscreening")
    qs = subjectscreening_cls.objects.all()
    for subjectscreening in tqdm(qs, total=qs.count()):
        subjectscreening.patient_log_identifier = (
            subjectscreening.patient_log.patient_log_identifier
        )
        subjectscreening.save_base(update_fields=["patient_log_identifier"])


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_screening",
            "0040_historicalsubjectscreening_patient_log_identifier_and_more",
        ),
    ]

    operations = [RunPython(update_patient_log_identifier)]



from .clinical_review_model_mixins import (
    ClinicalReviewBaselineDmModelMixin,
    ClinicalReviewBaselineHivModelMixin,
    ClinicalReviewBaselineHtnModelMixin,
    ClinicalReviewModelMixin,
)
from .crf_model_mixin import CrfModelMixin
from .crf_with_action_model_mixin import CrfWithActionModelMixin
from .followup_review_model_mixin import FollowupReviewModelMixin
from .medication_adherence_model_mixin import MedicationAdherenceModelMixin
from .search_slug_model_mixin import SearchSlugModelMixin
from .viral_load_result_model_mixin import ViralLoadResultModelMixin



from django.db import models
from django_crypto_fields.fields import EncryptedTextField
from edc_constants.choices import YES_NO
from edc_model.models import BaseUuidModel

from intecomm_subject.model_mixins import CrfModelMixin


class ClinicalNote(CrfModelMixin, BaseUuidModel):
    has_comment = models.CharField(
        verbose_name="Are there any aditional comments?",
        max_length=15,
        choices=YES_NO,
    )

    comments = EncryptedTextField(verbose_name="Comments", null=True, blank=True)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Clinical Note"
        verbose_name_plural = "Clinical Note"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from uuid import uuid4

from dateutil.relativedelta import relativedelta
from edc_constants.constants import MALE, NO, YES
from edc_utils import get_utcnow
from faker import Faker
from intecomm_form_validators import RECRUITING
from model_bakery.recipe import Recipe

from intecomm_lists.models import ConsentRefusalReasons

from .models import ConsentRefusal, PatientGroup, PatientLog, PatientLogUg

fake = Faker()

legal_name = fake.name().upper()
familiar_name = legal_name[0].upper()
names = legal_name.split(" ")
initials = f"{names[0][0]}{names[-1][0]}"


consentrefusal = Recipe(
    ConsentRefusal,
    report_datetime=get_utcnow(),
    reason=ConsentRefusalReasons.objects.get(name="dont_have_time"),
)

patientgroup = Recipe(
    PatientGroup,
    report_datetime=get_utcnow(),
    status=RECRUITING,
    randomize_now=NO,
    group_identifier=None,
    site=None,
)

patientlog = Recipe(
    PatientLog,
    legal_name=legal_name,
    familiar_name=familiar_name,
    initials=initials,
    report_datetime=get_utcnow(),
    consent_datetime=None,
    gender=MALE,
    may_contact=YES,
    stable=YES,
    last_appt_date=get_utcnow() - relativedelta(months=1),
    next_appt_date=get_utcnow() + relativedelta(months=1),
    first_health_talk=YES,
    second_health_talk=YES,
    call_attempts=1,
    willing_to_screen=YES,
    screening_refusal_reason=None,
    site=None,
)

patientlogug = Recipe(
    PatientLogUg,
    legal_name=str(uuid4()),
    familiar_name=str(uuid4()),
    initials=initials,
    report_datetime=get_utcnow(),
    consent_datetime=None,
    gender=MALE,
    may_contact=YES,
    stable=YES,
    last_appt_date=get_utcnow() - relativedelta(months=1),
    next_appt_date=get_utcnow() + relativedelta(months=1),
    first_health_talk=YES,
    second_health_talk=YES,
    call_attempts=1,
    willing_to_screen=YES,
    screening_refusal_reason=None,
)



# Generated by Django 4.2.3 on 2023-08-03 22:08

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0088_healtheconomicspatient_pat_employment_type_other_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.education",
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.ethnicities",
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_insurance",
            field=models.ManyToManyField(
                related_name="+",
                to="edc_he.insurancetypes",
                verbose_name="Household head’s health insurance and ‘club’ status ",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_education",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.education",
                verbose_name="Highest level of education completed?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_employment_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="What is your type of employment?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_ethnicity",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.ethnicities",
                verbose_name="What is your ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_insurance",
            field=models.ManyToManyField(
                related_name="+",
                to="edc_he.insurancetypes",
                verbose_name="What is your health insurance status?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_religion",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe your religious orientation?",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-11-21 23:00

import _socket
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_crypto_fields.fields.encrypted_char_field
import django_crypto_fields.fields.encrypted_text_field
import django_revision.revision_field
import edc_model.validators.phone
import edc_sites.models
import edc_utils.date
import intecomm_screening.model_mixins.patient_call_model_mixin
import simple_history.models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_screening", "0006_remove_historicalpatientcall_willing_to_attend_and_more"),
        ("intecomm_group", "0004_alter_patientgroup_patients"),
    ]

    operations = [
        migrations.CreateModel(
            name="PatientFollowupCall",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "contact_number",
                    django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                        blank=True,
                        help_text=" (Encryption: RSA local)",
                        max_length=71,
                        validators=[edc_model.validators.phone.phone_number],
                    ),
                ),
                (
                    "alt_contact_number",
                    django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                        blank=True,
                        help_text=" (Encryption: RSA local)",
                        max_length=71,
                        null=True,
                        validators=[edc_model.validators.phone.phone_number],
                    ),
                ),
                (
                    "answered",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")], max_length=15, null=True
                    ),
                ),
                (
                    "respondent",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("family", "Family"),
                            ("friend", "friend"),
                            ("other", "other"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                    ),
                ),
                (
                    "survival_status",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Is the participant known to be alive",
                    ),
                ),
                (
                    "catchment_area",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does the participant still reside within the catchment area",
                    ),
                ),
                (
                    "attend_date",
                    models.DateField(
                        blank=True, null=True, verbose_name="When can the patient next attend"
                    ),
                ),
                (
                    "call_again",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="May we call again?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        null=True,
                        verbose_name="Note",
                    ),
                ),
                (
                    "patient_log",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_screening.patientlog",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Patient Followup Call",
                "verbose_name_plural": "Patient Followup Calls",
                "ordering": ["report_datetime"],
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                (
                    "objects",
                    intecomm_screening.model_mixins.patient_call_model_mixin.Manager(),
                ),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalPatientFollowupCall",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "contact_number",
                    django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                        blank=True,
                        help_text=" (Encryption: RSA local)",
                        max_length=71,
                        validators=[edc_model.validators.phone.phone_number],
                    ),
                ),
                (
                    "alt_contact_number",
                    django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                        blank=True,
                        help_text=" (Encryption: RSA local)",
                        max_length=71,
                        null=True,
                        validators=[edc_model.validators.phone.phone_number],
                    ),
                ),
                (
                    "answered",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")], max_length=15, null=True
                    ),
                ),
                (
                    "respondent",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("family", "Family"),
                            ("friend", "friend"),
                            ("other", "other"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                    ),
                ),
                (
                    "survival_status",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Is the participant known to be alive",
                    ),
                ),
                (
                    "catchment_area",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does the participant still reside within the catchment area",
                    ),
                ),
                (
                    "attend_date",
                    models.DateField(
                        blank=True, null=True, verbose_name="When can the patient next attend"
                    ),
                ),
                (
                    "call_again",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="May we call again?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        null=True,
                        verbose_name="Note",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "patient_log",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_screening.patientlog",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Patient Followup Call",
                "verbose_name_plural": "historical Patient Followup Calls",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0063_alter_consentrefusal_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="patientcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "verbose_name": "Patient Call",
                "verbose_name_plural": "Patient Calls",
            },
        ),
        migrations.AddIndex(
            model_name="consentrefusal",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_810e6d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="consentrefusal",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_5255fb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalklog",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_d8ef96_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalklog",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_eea0dd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="oldhealthfacility",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_2d68e8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="oldhealthfacility",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_6c3bd9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientcall",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_4901ee_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientcall",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_8f9412_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlog",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_fa49a4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlog",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_08d139_idx"
            ),
        ),
    ]



from django.db import models
from edc_model.models import BaseUuidModel

from intecomm_facility.models import HealthFacility


# TODO: not used, Remove after migrations are squashed/reset
class IdentifierFormat(BaseUuidModel):
    old_health_facility = models.CharField(max_length=100, null=True)

    health_facility = models.ForeignKey(
        HealthFacility,
        verbose_name="Health facility",
        on_delete=models.PROTECT,
        null=True,
    )

    format_name = models.CharField(max_length=50)

    format_regex = models.CharField(max_length=150)

    comment = models.TextField(null=True, blank=True)

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Idenfifier format"
        verbose_name_plural = "Idenfifier formats"



# Generated by Django 4.1.7 on 2023-09-18 11:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0015_historicalsubjectconsentug"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentug",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-07-28 01:01

from django.db import migrations, models
import edc_crf.model_mixins.crf_status_model_mixin


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0067_auto_20230726_0008"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhba1cresult",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalhba1cresult",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalhba1cresult",
            name="subject_visit",
        ),
        migrations.RemoveField(
            model_name="historicalinvestigations",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalinvestigations",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalinvestigations",
            name="subject_visit",
        ),
        migrations.RemoveField(
            model_name="investigations",
            name="reason",
        ),
        migrations.RemoveField(
            model_name="investigations",
            name="site",
        ),
        migrations.RemoveField(
            model_name="investigations",
            name="subject_visit",
        ),
        migrations.AlterModelOptions(
            name="arvregimens",
            options={"verbose_name": "ARV Regimens", "verbose_name_plural": "ARV Regimens"},
        ),
        migrations.AlterModelOptions(
            name="historicalsubjectrequisition",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Subject requisition",
                "verbose_name_plural": "historical Subject requisitions",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalsubjectvisit",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Subject visit",
                "verbose_name_plural": "historical Subject visits",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalurinedipsticktest",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Urine dipstick test",
                "verbose_name_plural": "historical Urine dipstick tests",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalurinepregnancy",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Urine pregnancy test",
                "verbose_name_plural": "historical Urine pregnancy tests",
            },
        ),
        migrations.AlterModelOptions(
            name="malariatest",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Malaria Test",
                "verbose_name_plural": "Malaria Tests",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectrequisition",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Subject requisition",
                "verbose_name_plural": "Subject requisitions",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisit",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": (
                    "subject_identifier",
                    "visit_schedule_name",
                    "schedule_name",
                    "visit_code",
                    "visit_code_sequence",
                    "report_datetime",
                ),
                "verbose_name": "Subject visit",
                "verbose_name_plural": "Subject visits",
            },
        ),
        migrations.AlterModelOptions(
            name="urinedipsticktest",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Urine dipstick test",
                "verbose_name_plural": "Urine dipstick tests",
            },
        ),
        migrations.AlterModelOptions(
            name="urinepregnancy",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Urine pregnancy test",
                "verbose_name_plural": "Urine pregnancy tests",
            },
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="cd4result",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="cd4result",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalcd4result",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalcd4result",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectrequisition",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectrequisition",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="subjectrequisition",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="subjectrequisition",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.DeleteModel(
            name="Hba1cResult",
        ),
        migrations.DeleteModel(
            name="HistoricalHba1cResult",
        ),
        migrations.DeleteModel(
            name="HistoricalInvestigations",
        ),
        migrations.DeleteModel(
            name="Investigations",
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-10 21:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_screening", "0069_subjectscreeningtz_historicalsubjectscreeningtz"),
    ]

    operations = [
        migrations.AlterField(
            model_name="patientlog",
            name="conditions",
            field=models.ManyToManyField(
                limit_choices_to={"name__in": ["HIV", "dm", "htn"]},
                to="intecomm_lists.conditions",
                verbose_name="Diagnoses",
            ),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-10 17:41

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0154_careseekinga_missed_activities_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekinga",
            name="referral_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("public_clinic", "Public facility below tertiary level"),
                    ("private_clinic", "Private clinic"),
                    ("private_dx_facility", "Private diagnostic facility"),
                    ("ngo_clinic", "NGO clinic"),
                    ("public_hospital", "Public Hospital/tertiary facility"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFAC1",
                verbose_name="What type of facility have you been referred to?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="referral_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("inpatient", "Inpatient"),
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFTYPE1",
                verbose_name="Is this for inpatient or outpatient care?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="referral_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("public_clinic", "Public facility below tertiary level"),
                    ("private_clinic", "Private clinic"),
                    ("private_dx_facility", "Private diagnostic facility"),
                    ("ngo_clinic", "NGO clinic"),
                    ("public_hospital", "Public Hospital/tertiary facility"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFAC1",
                verbose_name="What type of facility have you been referred to?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="referral_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("inpatient", "Inpatient"),
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFTYPE1",
                verbose_name="Is this for inpatient or outpatient care?",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-03 15:28
from django.db import migrations
from edc_he.list_data import list_data
from edc_list_data import PreloadData
from tqdm import tqdm


def update_employment_type_and_education_on_he(apps, schema_editor):
    ld = {
        "edc_he.employmenttype": list_data.get("edc_he.employmenttype"),
        "edc_he.education": list_data.get("edc_he.education"),
    }
    PreloadData(list_data=ld, apps=apps)

    print("employment healtheconomicshouseholdhead\n")
    # employment
    list_model_cls = apps.get_model("edc_he.employmenttype")
    householdhead_cls = apps.get_model("intecomm_subject.healtheconomicshouseholdhead")
    total = householdhead_cls.objects.all().count()
    for obj in tqdm(householdhead_cls.objects.all(), total=total):
        if obj.hoh_employment_type_old == "3":
            hoh_employment_type_old = "2"
        else:
            hoh_employment_type_old = obj.hoh_employment_type_old
        list_model_obj = list_model_cls.objects.get(name=hoh_employment_type_old)
        obj.hoh_employment_type_id = list_model_obj.id
        obj.save_base(update_fields="hoh_employment_type")

    print("employment healtheconomicspatient\n")
    patient_cls = apps.get_model("intecomm_subject.healtheconomicspatient")
    total = patient_cls.objects.all().count()
    for obj in tqdm(patient_cls.objects.all(), total=total):
        if obj.pat_employment_type_old == "3":
            pat_employment_type_old = "2"
        else:
            pat_employment_type_old = obj.pat_employment_type_old
        list_model_obj = list_model_cls.objects.get(name=pat_employment_type_old)
        obj.pat_employment_type_id = list_model_obj.id
        obj.save_base(update_fields="pat_employment_type")

    # education
    print("education healtheconomicshouseholdhead\n")
    list_model_cls = apps.get_model("edc_he.education")
    householdhead_cls = apps.get_model("intecomm_subject.healtheconomicshouseholdhead")
    total = householdhead_cls.objects.all().count()
    for obj in tqdm(householdhead_cls.objects.all(), total=total):
        list_model_obj = list_model_cls.objects.get(name=obj.hoh_education_old)
        obj.hoh_education_id = list_model_obj.id
        obj.save_base(update_fields="hoh_education_id")

    print("education healtheconomicspatient\n")
    patient_cls = apps.get_model("intecomm_subject.healtheconomicspatient")
    total = patient_cls.objects.all().count()
    for obj in tqdm(patient_cls.objects.all(), total=total):
        list_model_obj = list_model_cls.objects.get(name=obj.pat_education_old)
        obj.pat_education_id = list_model_obj.id
        obj.save_base(update_fields="pat_education_id")


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0082_healtheconomicshouseholdhead_hoh_education_and_more"),
    ]

    operations = [migrations.RunPython(update_employment_type_and_education_on_he)]
